@@ -6,4 +6,7 @@ def smart_update_dict(dic1={},dic2={}):
             if isinstance(dic1[k],dict) and isinstance(dic2[k],dict):
                 smart_update_dict(dic1[k],dic2[k])
             else:
-                dic1[k]=v
\ No newline at end of file
+                dic1[k]=v
+def inrange(n,rg):
+    if n>=rg[0] and n<= rg[1]:return True
+    return False
\ No newline at end of file
