@@ -114,6 +114,10 @@ class FakeOS:
     def search(self,keywords,match_all=True):
         if not 'files' in self.cache.keys():
             self.cache['files']=self.glob('./**/*.*',recursive=True)
+            self.cache['last_refresh_time']=time.time()
+        elif time.time()-self.cache['last_refresh_time']>5*60*60:
+            self.cache['files'] = self.glob('./**/*.*', recursive=True)
+            self.cache['last_refresh_time'] = time.time()
         fs=self.cache['files']
         if match_all:
             for word in keywords:
@@ -142,11 +146,11 @@ class FakeOS:
         return open(file, mode)
     def openDB(self,path):
         path=self._truepath(path)
-        from wpkit.piu import BackupDB
+        from wk import BackupDB
         return BackupDB(path)
     def openFiledict(self,path):
         path=self._truepath(path)
-        from wpkit.piu import FileDict
+        from wk import FileDict
         return FileDict(path)
     def openObjectfile(self,path):
         path=self._truepath(path)
@@ -156,7 +160,7 @@ class FakeOS:
         return SimpleListFile(path)
     def openFolder(self,path):
         path=self._truepath(path)
-        from wpkit.fsutil import Folder
+        from wk import Folder
         return Folder(path)
     def dir(self,name):
         path=self._truepath(name)
