@@ -16,7 +16,7 @@ class FileServer(MyBlueprint):
 
         @self.route('/', methods=['get'])
         def do_root():
-            return node.QDocument().render()
+            return pages.SearchPageBase().render()
 
         @self.route('/search', methods=['post', 'get'])
         @parse_args
